Coverage report

# Coverage report: 81%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 422 | 79 | 0 | 81%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/__init__.py | 7 | 0 | 0 | 100%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/config.py | 12 | 1 | 0 | 92%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/helpers.py | 7 | 0 | 0 | 100%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/labels.py | 28 | 3 | 0 | 89%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/patterns.py | 16 | 0 | 0 | 100%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/utils.py | 352 | 75 | 0 | 79%

No items found using the specified filter.